package com.hfkj.service.order;

import com.hfkj.entity.BsGasOrder;
import com.hfkj.entity.BsMerchantUser;
import com.hfkj.entity.BsOrderChild;
import com.hfkj.model.order.OrderModel;
import com.hfkj.service.BsDeviceService;
import com.hfkj.service.merchant.BsMerchantAccountService;
import com.hfkj.service.merchant.BsMerchantUserService;
import com.hfkj.service.gas.BsGasOrderService;
import com.hfkj.sysenum.MerchantSourceTypeEnum;
import com.hfkj.sysenum.gas.OrderOilStatus;
import com.hfkj.sysenum.merchant.MerchantAccountRecordSourceTypeEnum;
import com.hfkj.sysenum.order.OrderChildProductTypeEnum;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: OrderPaySuccessService
 * @author: HuRui
 * @date: 2024/5/7
 **/
@Component
public class OrderPaySuccessService {
    Logger log = LoggerFactory.getLogger(OrderPaySuccessService.class);
    @Resource
    private BsOrderService orderService;
    @Resource
    private BsGasOrderService gasOrderService;
    @Resource
    private BsMerchantUserService merchantUserService;
    @Resource
    private BsDeviceService deviceService;
    @Resource
    private BsMerchantAccountService merchantAccountService;
    /**
     * 订单业务处理
     * @param order
     * @throws Exception
     */
    public void orderBusHandle(OrderModel order) {
        for (BsOrderChild childOrder : order.getOrderChildList()) {
            try {
                if (childOrder.getProductType().equals(OrderChildProductTypeEnum.type1.getCode())) {
                    oilHandle(order);
                }
             } catch (Exception e) {

            }
        }
    }

    /**
     * 加油业务
     * @param order
     */
    public void oilHandle(OrderModel order) throws Exception {
        // 查询加油订单
        BsGasOrder gasOrder = gasOrderService.getDetailByOrderNo(order.getOrderNo());
        if (gasOrder != null) {
            gasOrder.setPayIntegral(order.getDeduction().getIntegralDiscountPrice());
            gasOrder.setActualPayPrice(order.getPayRealPrice());
            gasOrder.setPayType(order.getPayType());
            gasOrder.setPayTime(order.getPayTime());
            gasOrder.setStatus(OrderOilStatus.STATUS2.getNumber());
            gasOrder.setPaySerialNo(order.getPaySerialNo());
            gasOrder.setPayChannelOrderNo(order.getPayChannelOrderNo());
            gasOrderService.updateGasOrder(gasOrder);

            if (gasOrder.getChannelType().equals(MerchantSourceTypeEnum.type1.getNumber())) {
                Map<String,Object> consumeMap = new HashMap<>();
                consumeMap.put("sourceType", MerchantAccountRecordSourceTypeEnum.type2.getType());
                consumeMap.put("sourceId", gasOrder.getId());
                consumeMap.put("sourceOrderNo", gasOrder.getOrderNo());
                merchantAccountService.consume(gasOrder.getMerNo(), gasOrder.getGasRefuelPrice(), consumeMap);
            }

            if (StringUtils.isNotBlank(gasOrder.getUserPhone())) {
                // 查询商户会员
                BsMerchantUser merchantUser = merchantUserService.getUser(gasOrder.getMerNo(), gasOrder.getUserPhone());
                if (merchantUser == null) {
                    // 注册商户会员
                    merchantUser = new BsMerchantUser();
                    merchantUser.setMerId(gasOrder.getMerId());
                    merchantUser.setMerNo(gasOrder.getMerNo());
                    merchantUser.setMerName(gasOrder.getMerName());
                    merchantUser.setUserId(gasOrder.getUserId());
                    merchantUser.setUserPhone(gasOrder.getUserPhone());
                    merchantUser.setVipLevel(0);
                    merchantUser.setIntegral(0);
                    merchantUser.setStatus(1);
                    merchantUserService.editData(merchantUser);
                }
                // TODO 赠送积分
            }

            // 打印小票
            if (gasOrder.getChannelType().equals(MerchantSourceTypeEnum.type1.getNumber())) {
                deviceService.printGasOrder(gasOrder.getMerId(), gasOrder, false );
            }
        }
    }

}
